@@ -8,6 +8,7 @@ from typing import Optional
 from typing import Sequence
 from typing import Tuple
 from typing import TYPE_CHECKING
+from typing import Union
 
 from pyrsistent import field
 from pyrsistent import m
@@ -22,8 +23,13 @@ from task_processing.plugins.kubernetes.types import EmptyVolume
 from task_processing.plugins.kubernetes.types import NodeAffinity
 from task_processing.plugins.kubernetes.types import NodeAffinityOperator
 from task_processing.plugins.kubernetes.types import ObjectFieldSelectorSource
+from task_processing.plugins.kubernetes.types import ProjectedSAVolume
 from task_processing.plugins.kubernetes.types import SecretVolume
 from task_processing.plugins.kubernetes.types import SecretVolumeItem
+from task_processing.plugins.kubernetes.types import TopologySpreadContraint
+from task_processing.plugins.kubernetes.utils import (
+    DEFAULT_PROJECTED_SA_TOKEN_EXPIRATION_SECONDS,
+)
 from task_processing.plugins.kubernetes.utils import get_sanitised_kubernetes_name
 from task_processing.plugins.kubernetes.utils import mode_to_int
 
@@ -190,6 +196,34 @@ def _valid_secret_volumes(
     return (True, None)
 
 
+def _valid_projected_sa_volumes(
+    sa_volumes: Sequence[ProjectedSAVolume],
+) -> Tuple[bool, Optional[str]]:
+    min_expiration = 600
+    for volume in sa_volumes:
+        if not volume.get("audience"):
+            return (
+                False,
+                "No token audience set for projected service account volume",
+            )
+        if not volume.get("container_path"):
+            return (
+                False,
+                "No token container_path set for projected service account volume",
+            )
+        if (
+            volume.get(
+                "expiration_seconds", DEFAULT_PROJECTED_SA_TOKEN_EXPIRATION_SECONDS
+            )
+            < min_expiration
+        ):
+            return (
+                False,
+                f"Expiration for service account projected token must be at least {min_expiration} seconds",
+            )
+    return (True, None)
+
+
 def _valid_secret_envs(
     secret_envs: Mapping[str, "SecretEnvSource"]
 ) -> Tuple[bool, Optional[str]]:
@@ -353,6 +387,12 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         factory=pvector,
         invariant=_valid_secret_volumes,
     )
+    projected_sa_volumes = field(
+        type=PVector if not TYPE_CHECKING else PVector["ProjectedSAVolume"],
+        initial=v(),
+        factory=pvector,
+        invariant=_valid_projected_sa_volumes,
+    )
 
     extra_containers = field(
         type=PMap if not TYPE_CHECKING else PMap[str, "KubernetesTaskConfig"],
@@ -435,6 +475,11 @@ class KubernetesTaskConfig(DefaultTaskConfigInterface):
         factory=pvector,
         invariant=_valid_node_affinities,
     )
+    topology_spread_constraints = field(
+        type=PVector if not TYPE_CHECKING else PVector["TopologySpreadContraint"],
+        initial=v(),
+        factory=pvector,
+    )
     labels = field(
         type=PMap if not TYPE_CHECKING else PMap[str, str],
         initial=m(),
